@@ -1,7 +1,7 @@
-from rest_framework.serializers import ModelSerializer
+from typing import List
 
 
 class ModelSerializerExtraFieldsMixin:
-    def get_field_names(self, declared_fields, info):
+    def get_field_names(self, declared_fields, info) -> List[str]:
         fields = super().get_field_names(declared_fields, info)
         return fields + getattr(self.Meta, "extra_fields", [])
